@@ -6,7 +6,7 @@ use text_io::read;
 use egg_mode::{
     auth::{access_token, authorize_url, request_token},
     error::{Error::TwitterError, TwitterErrors},
-    tweet::{like, mentions_timeline, Tweet},
+    tweet::{like, mentions_timeline, DraftTweet, Tweet},
     KeyPair, Token,
 };
 
@@ -37,7 +37,7 @@ struct Keys {
 
 type TwitterResult = Result<(), TwitterErrors>;
 
-const MENU_TEXT: &str = "(l)ike | (n)ext | e(x)it";
+const MENU_TEXT: &str = "(l)ike | (r)eply | (n)ext | e(x)it";
 
 async fn authenticate() -> Token {
     let key_file = home_dir().unwrap().join(".config/qt/keys.toml");
@@ -98,19 +98,23 @@ async fn send_like(tweet: &Tweet, token: &Token) -> TwitterResult {
     }
 }
 
-// async fn send_reply(tweet: &Tweet, reply_text: String, token: &Token) {
-//     // TODO should mention everyone in the thread, not just who was directly replied to
-//     let reply_text = format!(
-//         "@{} {}",
-//         tweet.user.as_ref().unwrap().screen_name,
-//         reply_text
-//     );
-//     DraftTweet::new(reply_text)
-//         .in_reply_to(tweet.id)
-//         .send(&token)
-//         .await
-//         .unwrap();
-// }
+async fn send_reply(tweet: &Tweet, reply_text: String, token: &Token) -> TwitterResult {
+    // TODO should mention everyone in the thread, not just who was directly replied to
+    let reply_text = format!(
+        "@{} {}",
+        tweet.user.as_ref().unwrap().screen_name,
+        reply_text
+    );
+    let result = DraftTweet::new(reply_text)
+        .in_reply_to(tweet.id)
+        .send(&token)
+        .await;
+    match result {
+        Ok(_) => Ok(()),
+        Err(TwitterError(_, e)) => Err(e),
+        Err(_) => panic!(),
+    }
+}
 
 fn err_view(errs: TwitterErrors) -> String {
     errs.errors[0].message.clone()
@@ -149,7 +153,12 @@ fn get_key() -> char {
     }
 }
 
-async fn run_action(tweet: &Tweet, key: char, token: &Token) -> String {
+async fn run_action(
+    tweet: &Tweet,
+    key: char,
+    token: &Token,
+    terminal: &mut Terminal<CrosstermBackend<Stdout>>,
+) -> String {
     if key == 'x' {
         stdout()
             .execute(terminal::Clear(terminal::ClearType::All))
@@ -160,7 +169,22 @@ async fn run_action(tweet: &Tweet, key: char, token: &Token) -> String {
     };
     if key == 'l' {
         match send_like(tweet, token).await {
-            Ok(()) => "Success".to_string(),
+            Ok(()) => "Done!".to_string(),
+            Err(e) => err_view(e),
+        }
+    } else if key == 'r' {
+        terminal::disable_raw_mode().unwrap();
+        draw(
+            tweet_view(tweet),
+            vec![Spans::from("Your reply:")],
+            terminal,
+        );
+        let height = terminal::size().unwrap().1;
+        stdout().execute(MoveTo(13, height - 2)).unwrap();
+        let reply = read!();
+        terminal::enable_raw_mode().unwrap();
+        match send_reply(tweet, reply, token).await {
+            Ok(()) => "Done!".to_string(),
             Err(e) => err_view(e),
         }
     } else {
@@ -194,8 +218,6 @@ fn draw(text_0: Vec<Spans>, text_1: Vec<Spans>, terminal: &mut Terminal<Crosster
             );
         })
         .unwrap();
-    let height = terminal::size().unwrap().1;
-    stdout().execute(MoveTo(3, height - 2)).unwrap();
 }
 
 #[tokio::main]
@@ -227,7 +249,7 @@ async fn main() {
                         vec![Spans::from("Working...")],
                         &mut terminal,
                     );
-                    run_action(&tweet, c, &token).await
+                    run_action(&tweet, c, &token, &mut terminal).await
                 }
             };
             draw(
